==> libjs-spectre_0.4.5.orig.tar.gz: spectre-0.4.5/CHANGELOG.md <==
## Spectre.css Changelog

### [v0.4.5](https://github.com/picturepan2/spectre/releases/tag/v0.4.5)

- Rewrite Off-canvas component
- Add `active` support to the Off-canvas #308
- Update the Docs pages

### [v0.4.4](https://github.com/picturepan2/spectre/releases/tag/v0.4.4)

- IMPORTANT: Increase default font sizes to 16px #271
- Add version number to CSS #288 #289

### [v0.4.3](https://github.com/picturepan2/spectre/releases/tag/v0.4.3)

- Add Icon Sizes #284
- Add Large Modals #293
- Update primary color to #5755d9
- Change Tooltips `white-space` to `pre` #292
- Encode SVG Data URI (thanks to @mariodev) #297 #298
- Improve Buttons and Forms small and large variables
- Improve Filters code
- Improve gulpfile and package
- Add Importing SASS Docs

### [v0.4.2](https://github.com/picturepan2/spectre/releases/tag/v0.4.2)

- Add Off-screen experimental
- Fix Docs rendering bug in Safari


### [v0.4.1](https://github.com/picturepan2/spectre/releases/tag/v0.4.1)

- Add default modifier to all variables 
- Add `address` reset which changes font-style to normal
- Add Details and Summary Accordions support
- Fix responsive video
- Update the Docs

### [v0.4.0](https://github.com/picturepan2/spectre/releases/tag/v0.4.0)

- Switch from LESS to SASS
- Add Cursor utilities

### [v0.3.2](https://github.com/picturepan2/spectre/releases/tag/v0.3.2)

- Add label-rounded classes
- Add Avatars presence status code
- Add Typography Fonts Docs
- Add Button variant mixins
- Update Autocomplete style
- Update Autoprefixer rules
- Update label mixin and code mono font family

### [v0.3.1](https://github.com/picturepan2/spectre/releases/tag/v0.3.1)

*IMPORTANT*: The default root font-size has been changed to `20px`, please update your `rem` numbers if you're using the custom sizes. [Learn more](https://picturepan2.github.io/spectre/getting-started.html#variables-sizes).

- Fix margin and padding utilities bug
- Add grid offset
- Rename Display utilities class names
- Move Panels and Empty states to Components from Layout
- Fix Docs bugs and cleanup codes

### [v0.2.15](https://github.com/picturepan2/spectre/releases/tag/v0.2.15)

- BIG Update to the Docs experience, completely rewritten and improved #240 
- Add Text and Background colors utilities #205 #219 
- Add Install from CDN option #191 
- Add unit size (4px) and unit size variables
- Add Responsive container (max width container) #222
- Add error and success states to checkbox, radio and switch #246 
- Fix Rem unit issue in East Asian Chrome #110 
- Fix icon direction bug #218
- Fix Dropdown menu max items/height #226 

## [v0.2.14](https://github.com/picturepan2/spectre/releases/tag/v0.2.14)

- Add vertical divider
- Add Form icon support
- Add Accordions
- Add anchor links to Docs
- Add new container grid size
- Fix link error and typo

### [v0.2.13](https://github.com/picturepan2/spectre/releases/tag/v0.2.13)

- Add Timelines code
- Add input readonly style
- Change Gulp building process and ignore /dist
- Change naming `danger` to `error`
- Change label-variant mixin
- Fix dropdown-toggle border radius in button groups
- Fix Calendars date item width bug under Firefox

### [v0.2.12](https://github.com/picturepan2/spectre/releases/tag/v0.2.12)

- Add pure CSS Comparison Sliders
- Add pure CSS content Filters
- Add Avatars badge support
- Add more icons
- Change :focus support
- Change Docs image sizes and add object-fit support
- Update Navbar code
- Fix typos, Modals bugs

### [v0.2.11](https://github.com/picturepan2/spectre/releases/tag/v0.2.11)

- Add pure CSS Popovers
- Add pure CSS Icons 
- Add Slider bars
- Add tvOS Parallax effect text layer
- Update shadow mixin

### [v0.2.10](https://github.com/picturepan2/spectre/releases/tag/v0.2.10)

- Add Shadows and Z-index variables
- Add Divider text
- Improve color variables
- Cleanup components code
- Remove the Responsive Resizer tool (Moved to https://github.com/picturepan2/responsive-resizer)

### [v0.2.9](https://github.com/picturepan2/spectre/releases/tag/v0.2.9)

- Add Panels layout: flexible view container layout with auto-expand content section
- Update Navbar layout
- Update docs and examples

### [v0.2.8](https://github.com/picturepan2/spectre/releases/tag/v0.2.8)

- Add Carousels previous and next buttons
- Improve disabled state for forms
- Improve calendar events style
- Improve Sliders disabled style
- Improve Autocomplete menu position
- Merge Menus and Dropdowns

### [v0.2.7](https://github.com/picturepan2/spectre/releases/tag/v0.2.7)

- Add Calendars experimental support
- Add tabindex note to the dropdowns docs
- Add shrink-to-fit=no to head meta
- Add Colors docs and update colors
- Fix wrong shadow colors with form-select
- Fix grid-480

### [v0.2.6](https://github.com/picturepan2/spectre/releases/tag/v0.2.6)

- Add Carousels initial experimental version
- Add Spectre.css Twitter account (@spectrecss) link
- Improve Docs experience and navbar
- Fix the bug of form input focus colors

### [v0.2.5](https://github.com/picturepan2/spectre/releases/tag/v0.2.5)

- Improve color variables completely
- Add Menu badges
- Add Responsive visibility (show-x)
- Add Parallax effect (pure CSS)
- Fix elements and components
- Update empty state layout code

### [v0.2.4](https://github.com/picturepan2/spectre/releases/tag/v0.2.4)

- ADD: Meters element experimental support
- ADD: Progress indeterminate animation
- ADD: Text-decoration-skip support
- CHG: Split Codes and improve docs codes
- FIX: Steps with tooltips z-index bug

### [v0.2.3](https://github.com/picturepan2/spectre/releases/tag/v0.2.3)

- Bars component
- Badges for buttons
- Experimentals CSS and docs
- Sliders experimental component
- A number of fixes as usual

### [v0.2.1](https://github.com/picturepan2/spectre/releases/tag/v0.2.1)

I have updated the whole Spectre.css documents experience and bumped the version to v0.2.x. The new Docs can be viewed at https://picturepan2.github.io/spectre/. Here are the new things added:
- New Docs experience with better navigations and better mobile off-canvas menu
- New components: Tiles, Steps and Navs (part of Navigation)
- Improvements: Action button, Autocomplete, Pagination, Tabs, Breadcrumbs, Badges, Cards,  new Progress experimental support and better focus style
- Fixes

Thank you. ♥

==> libjs-spectre_0.4.7.orig.tar.gz: spectre-0.4.7/CHANGELOG.md <==
## Spectre.css Changelog

### [v0.4.7](https://github.com/picturepan2/spectre/releases/tag/v0.4.7)

- Add new button colors (success and error) #227 #241 #342
- Add overflow-scrolling: touch; CSS for better scrolling
- Add touch support to Parallax image hover effect
- Update the Modal example code
- Fix form horizontal layout spacing

### [v0.4.6](https://github.com/picturepan2/spectre/releases/tag/v0.4.6)

- Add new Sliders example #328
- Add Table with horizontal scroll support #333
- Update Calendar event style which makes use of color utilities #326 
- Define $parallax-fade-color as default variable #332
- Fix the Docs content mistake
- Fix breadcrumb-item extra spacing #337
- Fix comparison slider image responsive bug #338

### [v0.4.5](https://github.com/picturepan2/spectre/releases/tag/v0.4.5)

- Rewrite Off-canvas component
- Add `active` support to the Off-canvas #308
- Update the Docs pages

### [v0.4.4](https://github.com/picturepan2/spectre/releases/tag/v0.4.4)

- IMPORTANT: Increase default font sizes to 16px #271
- Add version number to CSS #288 #289

### [v0.4.3](https://github.com/picturepan2/spectre/releases/tag/v0.4.3)

- Add Icon Sizes #284
- Add Large Modals #293
- Update primary color to #5755d9
- Change Tooltips `white-space` to `pre` #292
- Encode SVG Data URI (thanks to @mariodev) #297 #298
- Improve Buttons and Forms small and large variables
- Improve Filters code
- Improve gulpfile and package
- Add Importing Sass Docs

### [v0.4.2](https://github.com/picturepan2/spectre/releases/tag/v0.4.2)

- Add Off-screen experimental
- Fix Docs rendering bug in Safari


### [v0.4.1](https://github.com/picturepan2/spectre/releases/tag/v0.4.1)

- Add default modifier to all variables 
- Add `address` reset which changes font-style to normal
- Add Details and Summary Accordions support
- Fix responsive video
- Update the Docs

### [v0.4.0](https://github.com/picturepan2/spectre/releases/tag/v0.4.0)

- Switch from Less to Sass
- Add Cursor utilities

### [v0.3.2](https://github.com/picturepan2/spectre/releases/tag/v0.3.2)

- Add label-rounded classes
- Add Avatars presence status code
- Add Typography Fonts Docs
- Add Button variant mixins
- Update Autocomplete style
- Update Autoprefixer rules
- Update label mixin and code mono font family

### [v0.3.1](https://github.com/picturepan2/spectre/releases/tag/v0.3.1)

*IMPORTANT*: The default root font-size has been changed to `20px`, please update your `rem` numbers if you're using the custom sizes. [Learn more](https://picturepan2.github.io/spectre/getting-started.html#variables-sizes).

- Fix margin and padding utilities bug
- Add grid offset
- Rename Display utilities class names
- Move Panels and Empty states to Components from Layout
- Fix Docs bugs and cleanup codes

### [v0.2.15](https://github.com/picturepan2/spectre/releases/tag/v0.2.15)

- BIG Update to the Docs experience, completely rewritten and improved #240 
- Add Text and Background colors utilities #205 #219 
- Add Install from CDN option #191 
- Add unit size (4px) and unit size variables
- Add Responsive container (max width container) #222
- Add error and success states to checkbox, radio and switch #246 
- Fix Rem unit issue in East Asian Chrome #110 
- Fix icon direction bug #218
- Fix Dropdown menu max items/height #226 

## [v0.2.14](https://github.com/picturepan2/spectre/releases/tag/v0.2.14)

- Add vertical divider
- Add Form icon support
- Add Accordions
- Add anchor links to Docs
- Add new container grid size
- Fix link error and typo

### [v0.2.13](https://github.com/picturepan2/spectre/releases/tag/v0.2.13)

- Add Timelines code
- Add input readonly style
- Change Gulp building process and ignore /dist
- Change naming `danger` to `error`
- Change label-variant mixin
- Fix dropdown-toggle border radius in button groups
- Fix Calendars date item width bug under Firefox

### [v0.2.12](https://github.com/picturepan2/spectre/releases/tag/v0.2.12)

- Add pure CSS Comparison Sliders
- Add pure CSS content Filters
- Add Avatars badge support
- Add more icons
- Change :focus support
- Change Docs image sizes and add object-fit support
- Update Navbar code
- Fix typos, Modals bugs

### [v0.2.11](https://github.com/picturepan2/spectre/releases/tag/v0.2.11)

- Add pure CSS Popovers
- Add pure CSS Icons 
- Add Slider bars
- Add tvOS Parallax effect text layer
- Update shadow mixin

### [v0.2.10](https://github.com/picturepan2/spectre/releases/tag/v0.2.10)

- Add Shadows and Z-index variables
- Add Divider text
- Improve color variables
- Cleanup components code
- Remove the Responsive Resizer tool (Moved to https://github.com/picturepan2/responsive-resizer)

### [v0.2.9](https://github.com/picturepan2/spectre/releases/tag/v0.2.9)

- Add Panels layout: flexible view container layout with auto-expand content section
- Update Navbar layout
- Update docs and examples

### [v0.2.8](https://github.com/picturepan2/spectre/releases/tag/v0.2.8)

- Add Carousels previous and next buttons
- Improve disabled state for forms
- Improve calendar events style
- Improve Sliders disabled style
- Improve Autocomplete menu position
- Merge Menus and Dropdowns

### [v0.2.7](https://github.com/picturepan2/spectre/releases/tag/v0.2.7)

- Add Calendars experimental support
- Add tabindex note to the dropdowns docs
- Add shrink-to-fit=no to head meta
- Add Colors docs and update colors
- Fix wrong shadow colors with form-select
- Fix grid-480

### [v0.2.6](https://github.com/picturepan2/spectre/releases/tag/v0.2.6)

- Add Carousels initial experimental version
- Add Spectre.css Twitter account (@spectrecss) link
- Improve Docs experience and navbar
- Fix the bug of form input focus colors

### [v0.2.5](https://github.com/picturepan2/spectre/releases/tag/v0.2.5)

- Improve color variables completely
- Add Menu badges
- Add Responsive visibility (show-x)
- Add Parallax effect (pure CSS)
- Fix elements and components
- Update empty state layout code

### [v0.2.4](https://github.com/picturepan2/spectre/releases/tag/v0.2.4)

- ADD: Meters element experimental support
- ADD: Progress indeterminate animation
- ADD: Text-decoration-skip support
- CHG: Split Codes and improve docs codes
- FIX: Steps with tooltips z-index bug

### [v0.2.3](https://github.com/picturepan2/spectre/releases/tag/v0.2.3)

- Bars component
- Badges for buttons
- Experimentals CSS and docs
- Sliders experimental component
- A number of fixes as usual

### [v0.2.1](https://github.com/picturepan2/spectre/releases/tag/v0.2.1)

I have updated the whole Spectre.css documents experience and bumped the version to v0.2.x. The new Docs can be viewed at https://picturepan2.github.io/spectre/. Here are the new things added:
- New Docs experience with better navigations and better mobile off-canvas menu
- New components: Tiles, Steps and Navs (part of Navigation)
- Improvements: Action button, Autocomplete, Pagination, Tabs, Breadcrumbs, Badges, Cards,  new Progress experimental support and better focus style
- Fixes

Thank you. ♥
